<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Amazonrise
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function amazonrise_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	if ( 'none_sidebar' == get_theme_mod('amazonrise_general_layout', 'right_sidebar') || ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'none-sidebar';
	} elseif ( 'left_sidebar' == get_theme_mod('amazonrise_general_layout') ) {
		$classes[] = 'left-sidebar';
	} else {
		$classes[] = 'right-sidebar';
	}

	return $classes;
}
add_filter( 'body_class', 'amazonrise_body_classes' );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function amazonrise_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'amazonrise_pingback_header' );


 /**
 * A helper conditional function.
 * Whether there is a post thumbnail and post is not password protected.
 *
 * @return bool
 */
function amazonrise_has_post_thumbnail() {

	/**
	 * Post Thumbnail Filter
	 * @return bool
	 */
	return apply_filters( 'amazonrise_has_post_thumbnail', (bool) ( ! post_password_required() && has_post_thumbnail() ) );

}

/**
 * Remove color, header_image, background_image setting
 * @return bool
 */
function amazonrise_remove_customize_register( $wp_customize ) {

	$wp_customize->remove_section( 'colors');
	$wp_customize->remove_section( 'header_image');
	$wp_customize->remove_section( 'background_image');
}
add_action( 'customize_register', 'amazonrise_remove_customize_register',50 );