<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Amazonrise
 */


if ( ! function_exists( 'amazonrise_the_posts_navigation' ) ) {
	/**
	 |------------------------------------------------------------------------------
	 | Display navigation to next/previous set of posts when applicable.
	 |------------------------------------------------------------------------------
	 |
	 */
	function amazonrise_the_posts_navigation() {
		
		// Don't print empty markup if there's only one page.
		if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
			return;
		}

		$nav_style = get_theme_mod ('amazonrise_general_pagination_mode', 'default');

		if ( $nav_style == 'numberal' ) :
			
			// Previous/next page navigation.
			the_posts_pagination( array(
				'prev_text'				=> esc_html__( 'Previous page', 'amazonrise' ),
				'next_text'				=> esc_html__( 'Next page', 'amazonrise' ),
				'before_page_number'	=> '<span class="meta-nav screen-reader-text">' . esc_html__( 'Page', 'amazonrise' ) . ' </span>',
			) );
			
		else :
		?>

		<nav class="navigation paging-navigation clearfix" role="navigation">
			<span class="screen-reader-text"><?php esc_html_e( 'Posts navigation', 'amazonrise' ); ?></span>
			<div class="nav-links">

				<?php if ( get_next_posts_link() ) : ?>
					<div class="nav-previous"><span class="meta-nav">&larr;</span> <?php next_posts_link( esc_html__( 'Older posts', 'amazonrise' ) ); ?></div>
				<?php endif; ?>

				<?php if ( get_previous_posts_link() ) : ?>
					<div class="nav-next"><?php previous_posts_link( esc_html__( 'Newer posts', 'amazonrise' ) ); ?> <span class="meta-nav">&rarr;</span></div>
				<?php endif; ?>

			</div><!-- .nav-links -->
		</nav><!-- .navigation -->

		<?php
		endif;
	}
}


if ( ! function_exists( 'amazonrise_site_branding' ) ) {
	/**
	|------------------------------------------------------------------------------
	| Site Branding
	|------------------------------------------------------------------------------
	|
	| You can custom your logo here
	*/
	
	function amazonrise_site_branding() {
		?>
		<div class="site-branding">
			<?php if ( has_custom_logo() ) : ?>

				<div class="branding-logo">
					<?php the_custom_logo(); ?>
					
					<div class="branding-text">
						<?php amazonrise_site_logo(); ?>
					</div><!-- .branding-text -->
				</div><!-- .branding-logo -->

			<?php else : ?>

				<div class="branding-text">

					<?php amazonrise_site_logo(); ?>

				</div><!-- .branding-text -->

			<?php
			endif;
			?>
				<button type="button" id="aaaaaaaa" class="menu-toggle icon-toggle"><?php esc_html_e( 'Toggle Menu', 'amazonrise' ); ?></button>
				
		</div><!-- .site-branding -->
		<?php
	}
}


/**
 * Display a custom logo.
 *
 * @since 1.0.0
 */
function amazonrise_the_custom_logo() {

	/**
	 * For backwards compatibility prior to WordPress 4.5.
	 *
	 * @link  https://developer.wordpress.org/reference/functions/the_custom_logo/
	 * @since 1.0.0
	 */
	if ( function_exists( 'the_custom_logo' ) ) {

		the_custom_logo();

		return;

	}

	$custom_logo_id = get_theme_mod( 'custom_logo' );

	if ( ! $custom_logo_id && ! is_customize_preview() ) {

		return;

	}

	/**
	 * Filter the custom logo display args.
	 *
	 * @since 1.8.0
	 *
	 * @var array
	 */
	$args = (array) apply_filters( 'amazonrise_the_custom_logo_args', array(
		'class'    => 'custom-logo',
		'itemprop' => 'logo',
	) );

	printf( // xss ok.
		'<a href="%1$s" class="custom-logo-link" %2$s>%3$s</a>',
		esc_url( home_url( '/' ) ),
		$custom_logo_id ? 'rel="home" itemprop="url"' : 'style="display:none;"',
		$custom_logo_id ? wp_get_attachment_image( $custom_logo_id, 'full', false, $args ) : '<img class="custom-logo"/>'
	);

}


if ( ! function_exists( 'amazonrise_site_logo' ) ) {
	/**
	|------------------------------------------------------------------------------
	| Site Branding
	|------------------------------------------------------------------------------
	|
	| You can custom your logo here
	*/
	
	function amazonrise_site_logo() {

		if ( is_front_page() && is_home() ) : ?>
			<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
		<?php else : ?>
			<h2 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h2>
		<?php
		endif;

		$description = get_bloginfo( 'description', 'display' );
		if ( $description || is_customize_preview() ) : ?>
			<p class="site-description"><?php echo $description; /* WPCS: xss ok. */ ?></p>
		<?php
		endif;

	}
}


if ( ! function_exists( 'amazonrise_footer_copyright' ) ) {
	/**
	|------------------------------------------------------------------------------
	| Footer Copyright
	|------------------------------------------------------------------------------
	|
	| You can custom and remove footer copyright here
	*/
	
	function amazonrise_footer_copyright() {
		?>
		<a href="<?php echo esc_url( __( 'https://wordpress.org/', 'amazonrise' ) ); ?>">
			<?php
			/* translators: %s: CMS name, i.e. WordPress. */
			printf( esc_html__( 'Proudly powered by %s', 'amazonrise' ), 'WordPress' );
			?>
		</a>

		<span class="sep"> | </span>

		<?php
		/* translators: 1: Theme name, 2: Theme author. */
		printf( esc_html__( 'Theme %1$s by %2$s.', 'amazonrise' ), 'Amazonrise', '<a href="' . esc_url( __( 'http://opensumo.com/amazonrise/', 'amazonrise' ) ) . '">OpenSumo</a>' );

	}
}


if ( ! function_exists('amazonrise_related_posts') ) {
	/**
	|------------------------------------------------------------------------------
	| Related Posts
	|------------------------------------------------------------------------------
	|
	| You can show related posts by Categories or Tags. 
	| It has two options to show related posts
	|
	| 1. Thumbnail related posts (default)
	| 2. List of related posts
	| 
	| @return void
	|
	*/

	function amazonrise_related_posts() {
		
		global $post;

		$taxonomy = get_theme_mod('amazonrise_related_post_taxonomy', 'category');
		$numberRelated = get_theme_mod('amazonrise_number_related_posts', '6');

		$args =  array();

		if ( $taxonomy == 'tag' ) {

			$tags = wp_get_post_tags( $post->ID );
			$arr_tags = array();

			foreach( $tags as $tag ) {

				array_push($arr_tags, $tag->term_id);

			}
			
			if (!empty($arr_tags)) { 
				$args = array(
					'tag__in'			=> $arr_tags,  
					'post__not_in'		=> array($post->ID),  
					'posts_per_page'	=> $numberRelated,
				); 
			}

		} else {

			$args = array( 
				'category__in'		=> wp_get_post_categories($post->ID), 
				'posts_per_page'	=> $numberRelated, 
				'post__not_in'		=> array($post->ID) 
			);

		}

		if ( ! empty( $args ) ) {
			
			$posts = get_posts( $args );

			if ( $posts ) {
			?>

			<div class="posts-related clearfix">
				
				<h2 class="related-main-title"><?php esc_html_e('Related Post', 'amazonrise') ?></h2>
				
				<?php
					$related_style = 'grid';
					if ( $related_style == 'grid' ) :
				?>
					
					<ul class="related-grid">
						
						<?php
						foreach ( $posts as $p ) {
						?>
							
							<li>
										
								<?php if ( has_post_thumbnail( $p->ID ) ) : ?>

									<a href="<?php echo esc_url( get_the_permalink( $p->ID ) ) ?>">
										<?php echo get_the_post_thumbnail( $p->ID, 'amazonrise-small' ) ?>
									</a>

								<?php else : ?>

									<a href="<?php echo esc_url( get_the_permalink( $p->ID ) ) ?>">
										<img class="wp-post-image" src="<?php echo esc_url( get_template_directory_uri() ); ?>/images/default-small.jpg" alt="<?php the_title_attribute() ?>" />
									</a>

								<?php endif; ?>
								
								<h3 class="related-title">
									<a class="related-ptitle" href="<?php echo esc_url( get_the_permalink( $p->ID ) ) ?>"><?php echo esc_html( get_the_title( $p->ID ) ); ?></a>
								</h3>

							</li>

						<?php
							}
							wp_reset_postdata();
						?>

					</ul>

					<?php
						else :
					?>

					<ul class="related-list">
						
						<?php
						foreach ( $posts as $p ) {
							?>
							
							<li>												
																
								<a href="<?php echo esc_url( get_the_permalink($p->ID) ) ?>"><?php echo esc_html( get_the_title( $p->ID ) ); ?></a> 
							
							</li>

						<?php
							}
							wp_reset_postdata();
						?>
					</ul>

					<?php endif; ?>

				</div>
			
				<?php
			}
		}
	}
}


if ( ! function_exists( 'amazonrise_excerpt_length' ) ) {

	/**
	|------------------------------------------------------------------------------
	| Excerpt length | @return integer
	|------------------------------------------------------------------------------
	*/

	function amazonrise_excerpt_length($length) {

		if ( is_admin() ) {
			return $length;
		}

		$number = intval ( get_theme_mod('amazonrise_general_excerpt_lengh', 10) ) > 0 ? intval ( get_theme_mod('amazonrise_general_excerpt_lengh', 10) ) : $length;
		return $number;
	}
	
}

add_filter( 'excerpt_length', 'amazonrise_excerpt_length', 999 );


if ( ! function_exists( 'amazonrise_excerpt_more' ) ) {
	/**
	|------------------------------------------------------------------------------
	| Excerpt ending | @return string
	|------------------------------------------------------------------------------
	*/
	function amazonrise_excerpt_more( $more ) {
		if ( is_admin() ) {
			return $more;
		}
		return get_theme_mod( 'amazonrise_general_excerpt_end_text', ' ...' );
	}
	
}

add_filter( 'excerpt_more', 'amazonrise_excerpt_more' );


if ( ! function_exists( 'amazonrise_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 */
	function amazonrise_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( 'c' ) ),
			esc_html( get_the_modified_date() )
		);

		$posted_on = sprintf(
			/* translators: %s: post date. */
			esc_html_x( 'Posted on %s', 'post date', 'amazonrise' ),
			'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
		);

		$byline = sprintf(
			/* translators: %s: post author. */
			esc_html_x( 'by %s', 'post author', 'amazonrise' ),
			'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
		);

		echo '<span class="posted-on">' . $posted_on . '</span><span class="byline"> ' . $byline . '</span><!-- .entry-meta -->'; // WPCS: XSS OK.

	}
endif;

if ( ! function_exists( 'amazonrise_entry_categories' ) ) {
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function amazonrise_entry_categories() {

		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( esc_html__( ', ', 'amazonrise' ) );
		if ( $categories_list ) {
			/* translators: 1: list of categories. */
			printf( '<span class="entry-categories">' . esc_html__( 'Posted in %1$s', 'amazonrise' ) . '</span>', $categories_list ); // WPCS: XSS OK.
		}

	}
}

if ( ! function_exists( 'amazonrise_entry_footer' ) ) {
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function amazonrise_entry_footer() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'amazonrise' ) );
			if ( $categories_list ) {
				/* translators: 1: list of categories. */
				printf( '<span class="cat-links">' . esc_html__( 'Posted in %1$s', 'amazonrise' ) . '</span>', $categories_list ); // WPCS: XSS OK.
			}

			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'amazonrise' ) );
			if ( $tags_list ) {
				/* translators: 1: list of tags. */
				printf( '<span class="tags-links">' . esc_html__( 'Tagged %1$s', 'amazonrise' ) . '</span>', $tags_list ); // WPCS: XSS OK.
			}
		}

		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			comments_popup_link(
				sprintf(
					wp_kses(
						/* translators: %s: post title */
						__( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'amazonrise' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					get_the_title()
				)
			);
			echo '</span>';
		}

		edit_post_link(
			sprintf(
				wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
					__( 'Edit <span class="screen-reader-text">%s</span>', 'amazonrise' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				get_the_title()
			),
			'<span class="edit-link">',
			'</span>'
		);
	}
}

if ( ! function_exists( 'amazonrise_post_thumbnail' ) ) :
/**
 * Display an optional post thumbnail for archives.
 *
 * @param array $args
 * @return void
*/
function amazonrise_post_thumbnail( $args = array() ) {

	// Defaults
	$defaults = array (
 		'size'  => 'amazonrise-large',
 		'class' => 'post-content-thumbnail',
	);

	// Parse incoming $args into an array and merge it with $defaults
	$args = wp_parse_args( $args, $defaults );

	// Post Thumbnail Validation
	if ( amazonrise_has_post_thumbnail() ) {
		// Post Thumbnail URL
		$post_thumbnail_url = get_the_post_thumbnail_url( get_the_ID(), $args['size'] );

		// Post Thumbnail HTML
		printf( '<div class="%1$s"><a href="%2$s"><figure class="post-thumbnail" style="background-image: url(%3$s);"></figure></a></div>',
			esc_attr( $args['class'] ),
			esc_url( get_the_permalink() ),
			esc_url( $post_thumbnail_url )
		);
	} else {

		// Post Thumbnail URL
		$post_thumbnail_url = esc_url( get_template_directory_uri() ) . '/images/default-large.jpg';

		// Post Thumbnail HTML
		printf( '<div class="%1$s"><a href="%2$s"><figure class="post-thumbnail" style="background-image: url(%3$s);"></figure></a></div>',
			esc_attr( $args['class'] ),
			esc_url( get_the_permalink() ),
			esc_url( $post_thumbnail_url )
		);

	}
}
endif;